dev module — py-utilities 0.0.1 documentation

# dev module

## command_line_utilities

`py_utilities.dev.command_line_utilities.` `piped`(input=<open file '<stdin>', mode 'r' at 0x1036900c0>)

  Returns input if input is not connected to a tty(-like) device

`py_utilities.dev.command_line_utilities.` `prompt_yes_no`(prompt_msg, default=None, num_retries=5, input=<built-in function raw_input>)

  Yes/no prompts a user with prompt_msg. Default can be yes, no, or None. If user answer is not valid, he/she has num_retries to provide a valid yes/no prompt.

## dev_utilities

## profile_utilities